@@ -41,7 +41,8 @@ static std::wstring        userName(L"???");
 static size_t              areaWidth=16,areaHeight=16,areaBombs=40;
 static bool                oneButtonMode=false;
 std::vector<Theme>         themes;
-std::wstring               themeName(L"Internal Normal");
+std::wstring               themeName;
+std::wstring               zoomThemeName;
 
 void SetUserName(const std::wstring& name)
 {
@@ -94,26 +95,45 @@ bool LoadConfig()
 
   size_t boxSize=0;
 
-  if (Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
-    for (std::vector<Theme>::const_iterator theme=themes.begin();
-         theme!=themes.end();
-         ++theme)  {
-      if (theme->boxSize>boxSize) {
-        themeName=L"";
-        if (theme->name.find(L"Internal")==std::wstring::npos) {
-          boxSize=theme->boxSize;
-          themeName=theme->name;
-        }
-        else if (theme->name.find(L"Internal")!=std::wstring::npos &&
-          themeName.empty()) {
-          boxSize=theme->boxSize;
-          themeName=theme->name;
-          continue;
-        }
+  // Find the biggest theme available, prefer external themes
+  for (std::vector<Theme>::const_iterator theme=themes.begin();
+       theme!=themes.end();
+       ++theme)  {
+    if (theme->boxSize>=boxSize) {
+      if (theme->name.find(L"Internal")==std::wstring::npos) {
+        boxSize=theme->boxSize;
+        themeName=theme->name;
+      }
+
+      if (theme->name.find(L"Internal")!=std::wstring::npos) {
+        boxSize=theme->boxSize;
+        themeName=theme->name;
       }
     }
   }
 
+  size_t zoomBoxSize=boxSize;
+  zoomThemeName=themeName;
+
+  // Find the biggest theme available, prefer external themes
+  for (std::vector<Theme>::const_iterator theme=themes.begin();
+       theme!=themes.end();
+       ++theme)  {
+    if (theme->boxSize<=zoomBoxSize) {
+      if (theme->name.find(L"Internal")==std::wstring::npos) {
+        zoomBoxSize=theme->boxSize;
+        zoomThemeName=theme->name;
+      }
+
+      if (theme->name.find(L"Internal")!=std::wstring::npos) {
+        zoomBoxSize=theme->boxSize;
+        zoomThemeName=theme->name;
+      }
+    }
+  }
+
+  std::cout << "Theme: " << Lum::Base::WStringToString(themeName) << std::endl;
+
   // TODO: Find matching theme
 
   top=Lum::Config::LoadConfigFromXMLFile(path.GetPath(),errors);
